@@ -4,9 +4,10 @@ from .default_consumer import DefaultConsumer
 
 class BufferedConsumer(DefaultConsumer):
 
-    def __init__(self, product_id, data_source_id, server_host, max_size=50,
+    def __init__(self, product_id, data_source_id, server_host, data_parser=None,
+                 max_size=50,
                  retry_limit=3, request_timeout=2, retry_backoff_factor=0.25, verify_cert=True):
-        super(BufferedConsumer, self).__init__(product_id, data_source_id, server_host,
+        super(BufferedConsumer, self).__init__(product_id, data_source_id, server_host,data_parser,
                                                retry_limit, request_timeout, retry_backoff_factor, verify_cert)
         self._events = []
         self._max_size = min(200, max_size)
@@ -21,24 +22,14 @@ class BufferedConsumer(DefaultConsumer):
         else:
             request_url = self.endpoints['item']
             messages = [message]
-            data = self._data_parse.get_bytes(messages)
-            self.send_data(
-                request_url,
-                data,
-                headers={'content-type': 'application/json'}
-            )
+            self.post_data(request_url, messages)
 
     def _flush_event(self, request_url):
         buf = self._events
-
+        stm = self._data_parse.get_timestamp()
         while buf:
             batch = buf[:self._max_size]
-            data = self._data_parse.get_bytes(batch)
-            self.send_data(
-                request_url,
-                data,
-                headers={'content-type': 'application/json'}
-            )
+            self.post_data(request_url, batch)
             buf = buf[self._max_size:]
         self._events = buf
 
